@@ -1,10 +1,12 @@
-#[cfg(feature="with-serde")] use serde::{Serialize, Deserialize};
+#[cfg(feature = "with-serde")]
+use serde::{Deserialize, Serialize};
 
 use super::*;
 
 #[derive(Clone, Debug, PartialEq)]
 #[cfg_attr(feature = "with-serde", derive(Serialize, Deserialize))]
 pub struct Schema {
+    pub schema: String,
     pub system: SystemInfo,
     pub tables: Vec<TableDef>,
 }
