@@ -13,14 +13,10 @@ pub use table::*;
 pub use types::*;
 
 use super::def::Schema;
-use sea_query::SchemaStatement;
+use sea_query::TableCreateStatement;
 
 impl Schema {
-    pub fn write(&self) -> Vec<SchemaStatement> {
-        let mut statements = Vec::new();
-        for table in self.tables.iter() {
-            statements.push(SchemaStatement::TableStatement(table.write()));
-        }
-        statements
+    pub fn write(&self) -> Vec<TableCreateStatement> {
+        self.tables.iter().map(|table| table.write()).collect()
     }
 }
