@@ -1,11 +1,13 @@
 pub mod char_set;
 pub mod column;
 pub mod constraints;
+pub mod enumeration;
 pub mod schema;
 pub mod table;
 
 pub use char_set::*;
 pub use column::*;
 pub use constraints::*;
+pub use enumeration::*;
 pub use schema::*;
 pub use table::*;
